@@ -102,6 +102,13 @@ static struct _error_message
   0, ""}
 };
 
+static PyObject *
+_cubrid_return_PyUnicode_FromString (const char *buf, Py_ssize_t size, 
+        const char *encoding, const char *errors)
+{
+  return PyUnicode_Decode (buf, size, encoding, errors);
+}
+
 static PyObject *
 _cubrid_return_PyString_FromString (const char *buf)
 {
@@ -925,6 +932,7 @@ _cubrid_ConnectionObject_schema_to_pyvalue (_cubrid_ConnectionObject * self,
 #endif
 	  Py_DECREF (tmpval);
 	}
+      break;
     default:
       res = cci_get_data (request, index, CCI_A_TYPE_STR, &buffer, &ind);
       if (res < 0)
@@ -1314,9 +1322,35 @@ _cubrid_CursorObject_init (_cubrid_CursorObject * self, PyObject * args,
   self->row_count = -1;
   self->cursor_pos = 0;
 
+  memset(self->charset, 0, sizeof(self->charset));
+
   return 0;
 }
 
+static char _cubrid_CursorObject__set_charset_name__doc__[] =
+"Only used internally. This function should not be used by user.";
+
+static PyObject *
+_cubrid_CursorObject__set_charset_name (_cubrid_CursorObject * self, PyObject * args)
+{
+  char *charset = NULL;
+
+  if (!PyArg_ParseTuple (args, "s", &charset))
+    {
+      return NULL;
+    }
+
+  if (charset != NULL && *charset != '\0')
+    {
+      snprintf(self->charset, sizeof(self->charset), "%s", charset);
+    }
+
+  Py_INCREF (Py_None);
+  return Py_None;
+
+}
+
+
 static void
 _cubrid_CursorObject_reset (_cubrid_CursorObject * self)
 {
@@ -1961,7 +1995,14 @@ _cubrid_CursorObject_dbval_to_pyvalue (_cubrid_CursorObject * self, int type,
 	}
       else
 	{
-	  val = _cubrid_return_PyString_FromString (buffer);
+          if (self->charset != NULL && *(self->charset) != '\0')
+            {
+              val = _cubrid_return_PyUnicode_FromString (buffer, strlen(buffer), self->charset, NULL);
+            }
+          else
+            {
+              val = _cubrid_return_PyString_FromString (buffer);
+            }
 	}
       break;
     }
@@ -3027,6 +3068,11 @@ static PyMethodDef _cubrid_CursorObject_methods[] = {
    (PyCFunction) _cubrid_CursorObject_prepare,
    METH_VARARGS,
    _cubrid_CursorObject_prepare__doc__},
+  {
+   "_set_charset_name",
+   (PyCFunction) _cubrid_CursorObject__set_charset_name,
+   METH_VARARGS,
+   _cubrid_CursorObject__set_charset_name__doc__},
   {
    "bind_param",
    (PyCFunction) _cubrid_CursorObject_bind_param,
@@ -3345,7 +3391,7 @@ PyTypeObject _cubrid_CursorObject_type = {
   0,				/* tp_free */
 };
 
-#define _CUBRID_VERSION_	"8.4.3.0001"
+#define _CUBRID_VERSION_	"8.4.3.0002"
 static char _cubrid_doc[] = "CUBRID API Module for Python";
 
 #if PY_MAJOR_VERSION >= 3
